AGW Logo

svn SVN Revision 68455 For customtreectrl

This file contains the SVN revision history for customtreectrl, at revision 68455.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 10-Dec-2009 21:22:23 UTC
  • Committer: AG
  • File Size: 263649 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

CustomTreeCtrl: when expanding an item shows the vertical scrollbar, collapsing it leaves the scrollbar showing even if it’s no longer needed. Call AdjustMyScrollbars() inside the Collapse() method to prevent this behaviour. Thanks to Jill Holliday for the bug report and the patch.


svn_diff Diff To Previous Version (68439)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/customtreectrl.py     2011/07/27 17:17:15     68439
+++ wxPython/3rdParty/AGW/agw/customtreectrl.py     2011/07/29 20:09:55     68455
@@ -3,7 +3,7 @@
# Inspired By And Heavily Based On wxGenericTreeCtrl.
#
# Andrea Gavana, @ 17 May 2006
# Latest Revision: 27 Jul 2011, 19.00 GMT
#
#
# TODO List
@@ -212,7 +212,7 @@

CustomTreeCtrl is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 27 Jul 2011, 19.00 GMT
+Latest Revision: Andrea Gavana @ 29 Jul 2011, 21.00 GMT

Version 2.4

@@ -4666,6 +4666,8 @@

if self._hasWindows:
self.HideWindows()
+
+        self.AdjustMyScrollbars()

event.SetEventType(wxEVT_TREE_ITEM_COLLAPSED)
self.GetEventHandler().ProcessEvent(event)
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 17 May 2006
-# Latest Revision: 27 Jul 2011, 19.00 GMT
+# Latest Revision: 29 Jul 2011, 21.00 GMT
#
#
Tree